diff --git a/src/core/frontend/emu_window.cpp b/src/core/frontend/emu_window.cpp
index 8c1193894..589842917 100644
--- a/src/core/frontend/emu_window.cpp
+++ b/src/core/frontend/emu_window.cpp
@@ -30,12 +30,14 @@ private:
     class Device : public Input::TouchDevice {
     public:
         explicit Device(std::weak_ptr<TouchState>&& touch_state) : touch_state(touch_state) {}
-        std::tuple<float, float, bool> GetStatus() const override {
+        Input::TouchStatus GetStatus() const override {
+            Input::TouchStatus touch_status = {};
             if (auto state = touch_state.lock()) {
                 std::lock_guard guard{state->mutex};
-                return std::make_tuple(state->touch_x, state->touch_y, state->touch_pressed);
+                touch_status[0] =
+                    std::make_tuple(state->touch_x, state->touch_y, state->touch_pressed);
             }
-            return std::make_tuple(0.0f, 0.0f, false);
+            return touch_status;
         }
 
     private:
diff --git a/src/core/hle/service/hid/controllers/touchscreen.cpp b/src/core/hle/service/hid/controllers/touchscreen.cpp
index 13f75b48a..dc0d2c712 100644
--- a/src/core/hle/service/hid/controllers/touchscreen.cpp
+++ b/src/core/hle/service/hid/controllers/touchscreen.cpp
@@ -2,6 +2,7 @@
 // Licensed under GPLv2 or any later version
 // Refer to the license.txt file included.
 
+#include <algorithm>
 #include <cstring>
 #include "common/common_types.h"
 #include "core/core_timing.h"
@@ -16,7 +17,13 @@ constexpr std::size_t SHARED_MEMORY_OFFSET = 0x400;
 Controller_Touchscreen::Controller_Touchscreen(Core::System& system) : ControllerBase(system) {}
 Controller_Touchscreen::~Controller_Touchscreen() = default;
 
-void Controller_Touchscreen::OnInit() {}
+void Controller_Touchscreen::OnInit() {
+    for (size_t id = 0; id < MAX_FINGERS; id++) {
+        mouse_finger_id[id] = MAX_FINGERS;
+        keyboard_finger_id[id] = MAX_FINGERS;
+        udp_finger_id[id] = MAX_FINGERS;
+    }
+}
 
 void Controller_Touchscreen::OnRelease() {}
 
@@ -40,32 +47,35 @@ void Controller_Touchscreen::OnUpdate(const Core::Timing::CoreTiming& core_timin
     cur_entry.sampling_number = last_entry.sampling_number + 1;
     cur_entry.sampling_number2 = cur_entry.sampling_number;
 
-    updateTouchInputEvent(touch_mouse_device->GetStatus(), mouse_finger_id);
-    updateTouchInputEvent(touch_btn_device->GetStatus(), keyboard_finger_id);
-    updateTouchInputEvent(touch_udp_device->GetStatus(), udp_finger_id);
-
-    std::array<Finger, 16> sorted_fingers;
-    size_t active_fingers = 0;
-    for (Finger finger : fingers) {
-        if (finger.pressed) {
-            sorted_fingers[active_fingers++] = finger;
-        }
+    const Input::TouchStatus& mouse_status = touch_mouse_device->GetStatus();
+    const Input::TouchStatus& keyboard_status = touch_btn_device->GetStatus();
+    const Input::TouchStatus& udp_status = touch_udp_device->GetStatus();
+    for (size_t id = 0; id < mouse_status.size(); id++) {
+        mouse_finger_id[id] = UpdateTouchInputEvent(mouse_status[id], mouse_finger_id[id]);
+        keyboard_finger_id[id] = UpdateTouchInputEvent(keyboard_status[id], keyboard_finger_id[id]);
+        udp_finger_id[id] = UpdateTouchInputEvent(udp_status[id], udp_finger_id[id]);
     }
 
+    std::array<Finger, 16> active_fingers;
+    const auto end_iter = std::copy_if(fingers.begin(), fingers.end(), active_fingers.begin(),
+                                       [](const auto& finger) { return finger.pressed; });
+    const auto active_fingers_count =
+        static_cast<size_t>(std::distance(active_fingers.begin(), end_iter));
+
     const u64 tick = core_timing.GetCPUTicks();
-    cur_entry.entry_count = static_cast<s32_le>(active_fingers);
+    cur_entry.entry_count = static_cast<s32_le>(active_fingers_count);
     for (size_t id = 0; id < MAX_FINGERS; id++) {
         auto& touch_entry = cur_entry.states[id];
-        if (id < active_fingers) {
-            touch_entry.x = static_cast<u16>(sorted_fingers[id].x * Layout::ScreenUndocked::Width);
-            touch_entry.y = static_cast<u16>(sorted_fingers[id].y * Layout::ScreenUndocked::Height);
+        if (id < active_fingers_count) {
+            touch_entry.x = static_cast<u16>(active_fingers[id].x * Layout::ScreenUndocked::Width);
+            touch_entry.y = static_cast<u16>(active_fingers[id].y * Layout::ScreenUndocked::Height);
             touch_entry.diameter_x = Settings::values.touchscreen.diameter_x;
             touch_entry.diameter_y = Settings::values.touchscreen.diameter_y;
             touch_entry.rotation_angle = Settings::values.touchscreen.rotation_angle;
-            touch_entry.delta_time = tick - sorted_fingers[id].last_touch;
-            sorted_fingers[id].last_touch = tick;
-            touch_entry.finger = sorted_fingers[id].id;
-            touch_entry.attribute.raw = sorted_fingers[id].attribute.raw;
+            touch_entry.delta_time = tick - active_fingers[id].last_touch;
+            active_fingers[id].last_touch = tick;
+            touch_entry.finger = active_fingers[id].id;
+            touch_entry.attribute.raw = active_fingers[id].attribute.raw;
         } else {
             // Clear touch entry
             touch_entry.attribute.raw = 0;
@@ -91,44 +101,50 @@ void Controller_Touchscreen::OnLoadInputDevices() {
     }
 }
 
-void Controller_Touchscreen::updateTouchInputEvent(
-    const std::tuple<float, float, bool>& touch_input, size_t& finger_id) {
-    bool pressed = false;
-    float x, y;
-    std::tie(x, y, pressed) = touch_input;
-    if (pressed) {
-        if (finger_id == -1) {
-            int first_free_id = 0;
-            int found = false;
-            while (!found && first_free_id < MAX_FINGERS) {
-                if (!fingers[first_free_id].pressed) {
-                    found = true;
-                } else {
-                    first_free_id++;
-                }
-            }
-            if (found) {
-                finger_id = first_free_id;
-                fingers[finger_id].x = x;
-                fingers[finger_id].y = y;
-                fingers[finger_id].pressed = true;
-                fingers[finger_id].id = static_cast<u32_le>(finger_id);
-                fingers[finger_id].attribute.start_touch.Assign(1);
-            }
+std::optional<size_t> Controller_Touchscreen::GetUnusedFingerID() const {
+    size_t first_free_id = 0;
+    while (first_free_id < MAX_FINGERS) {
+        if (!fingers[first_free_id].pressed) {
+            return first_free_id;
         } else {
-            fingers[finger_id].x = x;
-            fingers[finger_id].y = y;
-            fingers[finger_id].attribute.raw = 0;
+            first_free_id++;
         }
-    } else if (finger_id != -1) {
+    }
+    return std::nullopt;
+}
+
+size_t Controller_Touchscreen::UpdateTouchInputEvent(
+    const std::tuple<float, float, bool>& touch_input, size_t finger_id) {
+    const auto& [x, y, pressed] = touch_input;
+    if (pressed) {
+        Attributes attribute = {};
+        if (finger_id == MAX_FINGERS) {
+            const auto first_free_id = GetUnusedFingerID();
+            if (!first_free_id) {
+                // Invalid finger id do nothing
+                return MAX_FINGERS;
+            }
+            finger_id = first_free_id.value();
+            fingers[finger_id].pressed = true;
+            fingers[finger_id].id = static_cast<u32_le>(finger_id);
+            attribute.start_touch.Assign(1);
+        }
+        fingers[finger_id].x = x;
+        fingers[finger_id].y = y;
+        fingers[finger_id].attribute = attribute;
+        return finger_id;
+    }
+
+    if (finger_id != MAX_FINGERS) {
         if (!fingers[finger_id].attribute.end_touch) {
             fingers[finger_id].attribute.end_touch.Assign(1);
             fingers[finger_id].attribute.start_touch.Assign(0);
-        } else {
-            fingers[finger_id].pressed = false;
-            finger_id = -1;
+            return finger_id;
         }
+        fingers[finger_id].pressed = false;
     }
+
+    return MAX_FINGERS;
 }
 
 } // namespace Service::HID
diff --git a/src/core/hle/service/hid/controllers/touchscreen.h b/src/core/hle/service/hid/controllers/touchscreen.h
index 03f399344..e39ab89ee 100644
--- a/src/core/hle/service/hid/controllers/touchscreen.h
+++ b/src/core/hle/service/hid/controllers/touchscreen.h
@@ -30,13 +30,17 @@ public:
     void OnLoadInputDevices() override;
 
 private:
+    static constexpr size_t MAX_FINGERS = 16;
+
+    // Returns an unused finger id, if there is no fingers available std::nullopt will be returned
+    std::optional<size_t> GetUnusedFingerID() const;
+
     // If the touch is new it tries to assing a new finger id, if there is no fingers avaliable no
     // changes will be made. Updates the coordinates if the finger id it's already set. If the touch
     // ends delays the output by one frame to set the end_touch flag before finally freeing the
     // finger id
-    void updateTouchInputEvent(const std::tuple<float, float, bool>& touch_input,
-                               size_t& finger_id);
-    static const size_t MAX_FINGERS = 16;
+    size_t UpdateTouchInputEvent(const std::tuple<float, float, bool>& touch_input,
+                                 size_t finger_id);
 
     struct Attributes {
         union {
@@ -88,9 +92,9 @@ private:
     std::unique_ptr<Input::TouchDevice> touch_mouse_device;
     std::unique_ptr<Input::TouchDevice> touch_udp_device;
     std::unique_ptr<Input::TouchDevice> touch_btn_device;
-    size_t mouse_finger_id{-1};
-    size_t keyboard_finger_id{-1};
-    size_t udp_finger_id{-1};
+    std::array<size_t, MAX_FINGERS> mouse_finger_id;
+    std::array<size_t, MAX_FINGERS> keyboard_finger_id;
+    std::array<size_t, MAX_FINGERS> udp_finger_id;
     std::array<Finger, MAX_FINGERS> fingers;
 };
 } // namespace Service::HID
diff --git a/src/input_common/touch_from_button.cpp b/src/input_common/touch_from_button.cpp
index a07124a86..5226e70df 100644
--- a/src/input_common/touch_from_button.cpp
+++ b/src/input_common/touch_from_button.cpp
@@ -25,18 +25,19 @@ public:
         }
     }
 
-    std::tuple<float, float, bool> GetStatus() const override {
-        for (const auto& m : map) {
-            const bool state = std::get<0>(m)->GetStatus();
+    Input::TouchStatus GetStatus() const override {
+        Input::TouchStatus touch_status = {};
+        for (size_t id = 0; id < map.size() && id < touch_status.size(); id++) {
+            const bool state = std::get<0>(map[id])->GetStatus();
             if (state) {
-                const float x = static_cast<float>(std::get<1>(m)) /
+                const float x = static_cast<float>(std::get<1>(map[id])) /
                                 static_cast<int>(Layout::ScreenUndocked::Width);
-                const float y = static_cast<float>(std::get<2>(m)) /
+                const float y = static_cast<float>(std::get<2>(map[id])) /
                                 static_cast<int>(Layout::ScreenUndocked::Height);
-                return {x, y, true};
+                touch_status[id] = {x, y, true};
             }
         }
-        return {};
+        return touch_status;
     }
 
 private:
diff --git a/src/input_common/udp/client.cpp b/src/input_common/udp/client.cpp
index 412d57896..53648cb53 100644
--- a/src/input_common/udp/client.cpp
+++ b/src/input_common/udp/client.cpp
@@ -136,6 +136,9 @@ static void SocketLoop(Socket* socket) {
 
 Client::Client() {
     LOG_INFO(Input, "Udp Initialization started");
+    for (size_t id = 0; id < MAX_TOUCH_FINGERS; id++) {
+        finger_id[id] = MAX_UDP_CLIENTS * 2;
+    }
     ReloadSockets();
 }
 
@@ -176,7 +179,7 @@ void Client::ReloadSockets() {
     std::string server_token;
     std::size_t client = 0;
     while (std::getline(servers_ss, server_token, ',')) {
-        if (client == max_udp_clients) {
+        if (client == MAX_UDP_CLIENTS) {
             break;
         }
         std::stringstream server_ss(server_token);
@@ -194,7 +197,7 @@ void Client::ReloadSockets() {
         for (std::size_t pad = 0; pad < 4; ++pad) {
             const std::size_t client_number =
                 GetClientNumber(udp_input_address, udp_input_port, pad);
-            if (client_number != max_udp_clients) {
+            if (client_number != MAX_UDP_CLIENTS) {
                 LOG_ERROR(Input, "Duplicated UDP servers found");
                 continue;
             }
@@ -213,7 +216,7 @@ std::size_t Client::GetClientNumber(std::string_view host, u16 port, std::size_t
             return client;
         }
     }
-    return max_udp_clients;
+    return MAX_UDP_CLIENTS;
 }
 
 void Client::OnVersion([[maybe_unused]] Response::Version data) {
@@ -259,33 +262,14 @@ void Client::OnPadData(Response::PadData data, std::size_t client) {
         std::lock_guard guard(clients[client].status.update_mutex);
         clients[client].status.motion_status = clients[client].motion.GetMotion();
 
-        // TODO: add a setting for "click" touch. Click touch refers to a device that differentiates
-        // between a simple "tap" and a hard press that causes the touch screen to click.
-        const bool is_active = data.touch_1.is_active != 0;
-
-        float x = 0;
-        float y = 0;
-
-        if (is_active && clients[client].status.touch_calibration) {
-            const u16 min_x = clients[client].status.touch_calibration->min_x;
-            const u16 max_x = clients[client].status.touch_calibration->max_x;
-            const u16 min_y = clients[client].status.touch_calibration->min_y;
-            const u16 max_y = clients[client].status.touch_calibration->max_y;
-
-            x = static_cast<float>(std::clamp(static_cast<u16>(data.touch_1.x), min_x, max_x) -
-                                   min_x) /
-                static_cast<float>(max_x - min_x);
-            y = static_cast<float>(std::clamp(static_cast<u16>(data.touch_1.y), min_y, max_y) -
-                                   min_y) /
-                static_cast<float>(max_y - min_y);
+        for (size_t id = 0; id < data.touch.size(); id++) {
+            UpdateTouchInput(data.touch[id], client, id);
         }
 
-        clients[client].status.touch_status = {x, y, is_active};
-
         if (configuring) {
             const Common::Vec3f gyroscope = clients[client].motion.GetGyroscope();
             const Common::Vec3f accelerometer = clients[client].motion.GetAcceleration();
-            UpdateYuzuSettings(client, accelerometer, gyroscope, is_active);
+            UpdateYuzuSettings(client, accelerometer, gyroscope);
         }
     }
 }
@@ -320,20 +304,16 @@ void Client::Reset() {
 }
 
 void Client::UpdateYuzuSettings(std::size_t client, const Common::Vec3<float>& acc,
-                                const Common::Vec3<float>& gyro, bool touch) {
+                                const Common::Vec3<float>& gyro) {
     if (gyro.Length() > 0.2f) {
-        LOG_DEBUG(Input, "UDP Controller {}: gyro=({}, {}, {}), accel=({}, {}, {}), touch={}",
-                  client, gyro[0], gyro[1], gyro[2], acc[0], acc[1], acc[2], touch);
+        LOG_DEBUG(Input, "UDP Controller {}: gyro=({}, {}, {}), accel=({}, {}, {})", client,
+                  gyro[0], gyro[1], gyro[2], acc[0], acc[1], acc[2]);
     }
     UDPPadStatus pad{
         .host = clients[client].host,
         .port = clients[client].port,
         .pad_index = clients[client].pad_index,
     };
-    if (touch) {
-        pad.touch = PadTouch::Click;
-        pad_queue.Push(pad);
-    }
     for (size_t i = 0; i < 3; ++i) {
         if (gyro[i] > 5.0f || gyro[i] < -5.0f) {
             pad.motion = static_cast<PadMotion>(i);
@@ -348,6 +328,53 @@ void Client::UpdateYuzuSettings(std::size_t client, const Common::Vec3<float>& a
     }
 }
 
+std::optional<size_t> Client::GetUnusedFingerID() const {
+    size_t first_free_id = 0;
+    while (first_free_id < MAX_TOUCH_FINGERS) {
+        if (!std::get<2>(touch_status[first_free_id])) {
+            return first_free_id;
+        } else {
+            first_free_id++;
+        }
+    }
+    return std::nullopt;
+}
+
+void Client::UpdateTouchInput(Response::TouchPad& touch_pad, size_t client, size_t id) {
+    // TODO: Use custom calibration per device
+    const Common::ParamPackage touch_param(Settings::values.touch_device);
+    const u16 min_x = static_cast<u16>(touch_param.Get("min_x", 100));
+    const u16 min_y = static_cast<u16>(touch_param.Get("min_y", 50));
+    const u16 max_x = static_cast<u16>(touch_param.Get("max_x", 1800));
+    const u16 max_y = static_cast<u16>(touch_param.Get("max_y", 850));
+
+    if (touch_pad.is_active) {
+        if (finger_id[client * 2 + id] == MAX_TOUCH_FINGERS) {
+            const auto first_free_id = GetUnusedFingerID();
+            if (!first_free_id) {
+                // Invalid finger id skip to next input
+                return;
+            }
+            finger_id[client * 2 + id] = first_free_id.value();
+        }
+        auto& [x, y, pressed] = touch_status[finger_id[client * 2 + id]];
+        x = static_cast<float>(std::clamp(static_cast<u16>(touch_pad.x), min_x, max_x) - min_x) /
+            static_cast<float>(max_x - min_x);
+        y = static_cast<float>(std::clamp(static_cast<u16>(touch_pad.y), min_y, max_y) - min_y) /
+            static_cast<float>(max_y - min_y);
+        pressed = true;
+        return;
+    }
+
+    if (finger_id[client * 2 + id] != MAX_TOUCH_FINGERS) {
+        auto& [x, y, pressed] = touch_status[finger_id[client * 2 + id]];
+        x = 0;
+        y = 0;
+        pressed = false;
+        finger_id[client * 2 + id] = MAX_TOUCH_FINGERS;
+    }
+}
+
 void Client::BeginConfiguration() {
     pad_queue.Clear();
     configuring = true;
@@ -360,7 +387,7 @@ void Client::EndConfiguration() {
 
 DeviceStatus& Client::GetPadState(const std::string& host, u16 port, std::size_t pad) {
     const std::size_t client_number = GetClientNumber(host, port, pad);
-    if (client_number == max_udp_clients) {
+    if (client_number == MAX_UDP_CLIENTS) {
         return clients[0].status;
     }
     return clients[client_number].status;
@@ -368,12 +395,20 @@ DeviceStatus& Client::GetPadState(const std::string& host, u16 port, std::size_t
 
 const DeviceStatus& Client::GetPadState(const std::string& host, u16 port, std::size_t pad) const {
     const std::size_t client_number = GetClientNumber(host, port, pad);
-    if (client_number == max_udp_clients) {
+    if (client_number == MAX_UDP_CLIENTS) {
         return clients[0].status;
     }
     return clients[client_number].status;
 }
 
+Input::TouchStatus& Client::GetTouchState() {
+    return touch_status;
+}
+
+const Input::TouchStatus& Client::GetTouchState() const {
+    return touch_status;
+}
+
 Common::SPSCQueue<UDPPadStatus>& Client::GetPadQueue() {
     return pad_queue;
 }
@@ -426,24 +461,24 @@ CalibrationConfigurationJob::CalibrationConfigurationJob(
                                         current_status = Status::Ready;
                                         status_callback(current_status);
                                     }
-                                    if (data.touch_1.is_active == 0) {
+                                    if (data.touch[0].is_active == 0) {
                                         return;
                                     }
-                                    LOG_DEBUG(Input, "Current touch: {} {}", data.touch_1.x,
-                                              data.touch_1.y);
-                                    min_x = std::min(min_x, static_cast<u16>(data.touch_1.x));
-                                    min_y = std::min(min_y, static_cast<u16>(data.touch_1.y));
+                                    LOG_DEBUG(Input, "Current touch: {} {}", data.touch[0].x,
+                                              data.touch[0].y);
+                                    min_x = std::min(min_x, static_cast<u16>(data.touch[0].x));
+                                    min_y = std::min(min_y, static_cast<u16>(data.touch[0].y));
                                     if (current_status == Status::Ready) {
                                         // First touch - min data (min_x/min_y)
                                         current_status = Status::Stage1Completed;
                                         status_callback(current_status);
                                     }
-                                    if (data.touch_1.x - min_x > CALIBRATION_THRESHOLD &&
-                                        data.touch_1.y - min_y > CALIBRATION_THRESHOLD) {
+                                    if (data.touch[0].x - min_x > CALIBRATION_THRESHOLD &&
+                                        data.touch[0].y - min_y > CALIBRATION_THRESHOLD) {
                                         // Set the current position as max value and finishes
                                         // configuration
-                                        max_x = data.touch_1.x;
-                                        max_y = data.touch_1.y;
+                                        max_x = data.touch[0].x;
+                                        max_y = data.touch[0].y;
                                         current_status = Status::Completed;
                                         data_callback(min_x, min_y, max_x, max_y);
                                         status_callback(current_status);
diff --git a/src/input_common/udp/client.h b/src/input_common/udp/client.h
index 00c8b09f5..1cd251ec8 100644
--- a/src/input_common/udp/client.h
+++ b/src/input_common/udp/client.h
@@ -29,6 +29,7 @@ namespace Response {
 struct PadData;
 struct PortInfo;
 struct Version;
+struct TouchPad;
 } // namespace Response
 
 enum class PadMotion {
@@ -50,7 +51,6 @@ struct UDPPadStatus {
     std::string host{"127.0.0.1"};
     u16 port{26760};
     std::size_t pad_index{};
-    PadTouch touch{PadTouch::Undefined};
     PadMotion motion{PadMotion::Undefined};
     f32 motion_value{0.0f};
 };
@@ -93,6 +93,9 @@ public:
     DeviceStatus& GetPadState(const std::string& host, u16 port, std::size_t pad);
     const DeviceStatus& GetPadState(const std::string& host, u16 port, std::size_t pad) const;
 
+    Input::TouchStatus& GetTouchState();
+    const Input::TouchStatus& GetTouchState() const;
+
 private:
     struct ClientData {
         std::string host{"127.0.0.1"};
@@ -122,14 +125,25 @@ private:
     void StartCommunication(std::size_t client, const std::string& host, u16 port,
                             std::size_t pad_index, u32 client_id);
     void UpdateYuzuSettings(std::size_t client, const Common::Vec3<float>& acc,
-                            const Common::Vec3<float>& gyro, bool touch);
+                            const Common::Vec3<float>& gyro);
+
+    // Returns an unused finger id, if there is no fingers available std::nullopt will be
+    // returned
+    std::optional<size_t> GetUnusedFingerID() const;
+
+    // Merges and updates all touch inputs into the touch_status array
+    void UpdateTouchInput(Response::TouchPad& touch_pad, size_t client, size_t id);
 
     bool configuring = false;
 
     // Allocate clients for 8 udp servers
-    const std::size_t max_udp_clients = 32;
-    std::array<ClientData, 4 * 8> clients;
-    Common::SPSCQueue<UDPPadStatus> pad_queue;
+    static constexpr std::size_t MAX_UDP_CLIENTS = 4 * 8;
+    // Each client can have up 2 touch inputs
+    static constexpr std::size_t MAX_TOUCH_FINGERS = MAX_UDP_CLIENTS * 2;
+    std::array<ClientData, MAX_UDP_CLIENTS> clients{};
+    Common::SPSCQueue<UDPPadStatus> pad_queue{};
+    Input::TouchStatus touch_status{};
+    std::array<size_t, MAX_TOUCH_FINGERS> finger_id{};
 };
 
 /// An async job allowing configuration of the touchpad calibration.
diff --git a/src/input_common/udp/protocol.h b/src/input_common/udp/protocol.h
index fc1aea4b9..a3d276697 100644
--- a/src/input_common/udp/protocol.h
+++ b/src/input_common/udp/protocol.h
@@ -140,6 +140,14 @@ static_assert(sizeof(PortInfo) == 12, "UDP Response PortInfo struct has wrong si
 static_assert(std::is_trivially_copyable_v<PortInfo>,
               "UDP Response PortInfo is not trivially copyable");
 
+struct TouchPad {
+    u8 is_active{};
+    u8 id{};
+    u16_le x{};
+    u16_le y{};
+};
+static_assert(sizeof(TouchPad) == 6, "UDP Response TouchPad struct has wrong size ");
+
 #pragma pack(push, 1)
 struct PadData {
     PortInfo info{};
@@ -190,12 +198,7 @@ struct PadData {
         u8 button_13{};
     } analog_button;
 
-    struct TouchPad {
-        u8 is_active{};
-        u8 id{};
-        u16_le x{};
-        u16_le y{};
-    } touch_1, touch_2;
+    std::array<TouchPad, 2> touch;
 
     u64_le motion_timestamp;
 
@@ -222,7 +225,6 @@ static_assert(sizeof(Message<PadData>) == MAX_PACKET_SIZE,
 
 static_assert(sizeof(PadData::AnalogButton) == 12,
               "UDP Response AnalogButton struct has wrong size ");
-static_assert(sizeof(PadData::TouchPad) == 6, "UDP Response TouchPad struct has wrong size ");
 static_assert(sizeof(PadData::Accelerometer) == 12,
               "UDP Response Accelerometer struct has wrong size ");
 static_assert(sizeof(PadData::Gyroscope) == 12, "UDP Response Gyroscope struct has wrong size ");
diff --git a/src/input_common/udp/udp.cpp b/src/input_common/udp/udp.cpp
index c5da27a38..b630281a0 100644
--- a/src/input_common/udp/udp.cpp
+++ b/src/input_common/udp/udp.cpp
@@ -78,8 +78,8 @@ public:
     explicit UDPTouch(std::string ip_, u16 port_, u16 pad_, CemuhookUDP::Client* client_)
         : ip(std::move(ip_)), port(port_), pad(pad_), client(client_) {}
 
-    std::tuple<float, float, bool> GetStatus() const override {
-        return client->GetPadState(ip, port, pad).touch_status;
+    Input::TouchStatus GetStatus() const override {
+        return client->GetTouchState();
     }
 
 private:
@@ -107,32 +107,4 @@ std::unique_ptr<Input::TouchDevice> UDPTouchFactory::Create(const Common::ParamP
     return std::make_unique<UDPTouch>(std::move(ip), port, pad, client.get());
 }
 
-void UDPTouchFactory::BeginConfiguration() {
-    polling = true;
-    client->BeginConfiguration();
-}
-
-void UDPTouchFactory::EndConfiguration() {
-    polling = false;
-    client->EndConfiguration();
-}
-
-Common::ParamPackage UDPTouchFactory::GetNextInput() {
-    Common::ParamPackage params;
-    CemuhookUDP::UDPPadStatus pad;
-    auto& queue = client->GetPadQueue();
-    while (queue.Pop(pad)) {
-        if (pad.touch == CemuhookUDP::PadTouch::Undefined) {
-            continue;
-        }
-        params.Set("engine", "cemuhookudp");
-        params.Set("ip", pad.host);
-        params.Set("port", static_cast<u16>(pad.port));
-        params.Set("pad_index", static_cast<u16>(pad.pad_index));
-        params.Set("touch", static_cast<u16>(pad.touch));
-        return params;
-    }
-    return params;
-}
-
 } // namespace InputCommon
diff --git a/src/yuzu/configuration/config.cpp b/src/yuzu/configuration/config.cpp
index 0ec358225..5e4d22299 100644
--- a/src/yuzu/configuration/config.cpp
+++ b/src/yuzu/configuration/config.cpp
@@ -557,7 +557,8 @@ void Config::ReadMotionTouchValues() {
             .toString()
             .toStdString();
     Settings::values.touch_device =
-        ReadSetting(QStringLiteral("touch_device"), QStringLiteral("engine:emu_window"))
+        ReadSetting(QStringLiteral("touch_device"),
+                    QStringLiteral("min_x:100,min_y:50,max_x:1800,max_y:850"))
             .toString()
             .toStdString();
     Settings::values.use_touch_from_button =
diff --git a/src/core/frontend/input.h b/src/core/frontend/input.h
index de51a754e..f014dfea3 100644
--- a/src/core/frontend/input.h
+++ b/src/core/frontend/input.h
@@ -163,10 +163,11 @@ using MotionStatus = std::tuple<Common::Vec3<float>, Common::Vec3<float>, Common
 using MotionDevice = InputDevice<MotionStatus>;
 
 /**
  * A touch status is an object that returns a tuple of two floats and a bool. The floats are
  * x and y coordinates in the range 0.0 - 1.0, and the bool indicates whether it is pressed.
  */
-using TouchStatus = std::tuple<float, float, bool>;
+using TouchStatus = std::array<std::tuple<float, float, bool>, 16>;
 
 /**
  * A touch device is an input device that returns a touch status object
@@ -163,10 +163,11 @@ using MotionStatus = std::tuple<Common::Vec3<float>, Common::Vec3<float>, Common
 
 /**
- * A touch status is an object that returns a tuple of two floats and a bool. The floats are
- * x and y coordinates in the range 0.0 - 1.0, and the bool indicates whether it is pressed.
+ * A touch status is an object that returns an array of 16 tuple elements of two floats and a bool.
+ * The floats are x and y coordinates in the range 0.0 - 1.0, and the bool indicates whether it is
+ * pressed.
  */